# Formation ConvertKit Backup

Dans cette formation, tu pourras mettre en place une sauvegarde de ConvertKit sur la plateforme GitLab qui inclus notamment les contacts, les campagnes et les tags.

Comme leur API est en cours de développement, on ne peut pas encore tout extraire ce qui est disponible dans l'interface via l'API, donc le contenu présenté ici sera appelé à évoluer.

La structure générale des abonnements dans ConvertKit est hiérarchique, ce qui nous demandera d'utiliser un système de pagination à deux niveaux:

![](images/pagination-formulaire-abonnes.drawio.png)

Cette partie demande quelques minutes à s'exécuter sur les plus gros comptes.

Cette formation a été testée sur la version de GitLab 14.10.0 et la version de l'API de ConvertKit au 4 juillet 2022.

Ceci va te créer une archive dans le système GitLab qui permettra de reculer dans le temps à partir de la première fois où on va exécuter notre sauvegarde.

## Les prérequis

Je te présente ici une liste des outils nécessaires pour faire cette formation

- [ ] Être sur un ordinateur. Tous les systèmes sont supportés: Windows, macOS ou Linux. Ce tutoriel n'est pas conçu sur mobile.
- [ ] Un navigateur web récent. Les captures d'écran seront basées sur Google Chrome (Brave ou Edge sont équivalents), ce pourrait être différent pour Opera, Safari ou Firefox.
- [ ] Un éditeur de texte (et non un traitement de texte). Je te conseille [Notepad++](https://notepad-plus-plus.org/downloads/) sur Windows. Sur macOS, tu peux utiliser TextEdit. Ce sera utile pour copier-coller des informations et utiliser le fichier d'accompagnement `Compagnon.txt`.
- [ ] Une carte de crédit. Pour activer la fonctionnalité CI/CD, tu devras fournir les informations, mais elle ne sera pas chargée. CI/CD signifie Continuous integration and delivery ou Intégration et livraison continue en français. C'est une méthode d'automatisation de tâches utilisée couramment en génie logiciel. Comme elle consomme les processeurs de GitLab, son utilisation est limitée dans le forfait gratuit.

## Notes importantes

- Cette formation est offerte telle quelle, sans garantie de résultats (mais, pour te rassurer, je l'ai testé depuis quelques semaines !
- Si le site web ConvertKit change de fonctionnement, cette procédure ne fonctionnera plus et devra être adaptée.
- J'ai repris certaines captures de ma [formation de sauvegardes pour Notion](https://jevalideca.ck.page/82b2ff46e3). Tu n'auras qu'à remplacer Notion par ConvertKit

## Variables d’environnement pour l’API de ConvertKit

Nous allons avoir besoin de deux variables d’environnement pour que GitLab puisse se connecter à ConvertKit automatiquement. Ce sont les jetons d’application. Ils sont fournis par ConvertKit dans la section Settings / Advanced / API.

![](images/convertkit_api_tokens-1024x661.png)

Nous nommerons ces deux variables comme suit dans GitLab:

- `CONVERTKIT_API_KEY`
- `CONVERTKIT_API_SECRET`

## Configurer les variables de CI/CD dans GitLab

## Ouvrir un compte chez GitLab.com

Pour ouvrir un compte, visite cette adresse: [https://gitlab.com/users/sign_up](https://gitlab.com/users/sign_up). Entre les informations demandées.

Conserve ton mot de passe précieusement dans un gestionnaire de mot de passe, car ce compte aura accès à tout le contenu de ton espace Notion.

![ouvrir un compte GitLab](images/creer_gitlab.png)

Tu vas ensuite recevoir un courriel de validation pour activer ton compte. Ça va t'amener à une fenêtre pour personnaliser ton compte.

![personnaliser ton compte](images/personnaliser_gitlab.png)

Tu vas ensuite être invité à créer un groupe et un projet. Tu peux compléter ça comme suit.

![créer un groupe et un projet](images/gitlab_nouveau_projet.png)

Après quelques fenêtres, tu devrais arriver à la page d'accueil de GitLab.

## Configurer l'environnement GitLab

Nous allons maintenant configurer GitLab pour exécuter les sauvegardes. Comme nous allons automatiser une opération qui va modifier le contenu du projet que nous avons créé, nous avons besoin d'un jeton d'accès.

Pour le créer, nous allons dans le profil personnel, à partir du menu en haut à gauche, puis `Edit Profile`

![profil personnel](images/gitlab_menu_profile.png)

### Obtenir le jeton pour le CI/CD de GitLab

Dans le menu de gauche, clique sur Access Tokens

![Access Tokens](images/access_token_menu.png)

Nomme le jeton `notionbackup`, et coche la permission `write_repository`. Ensuite, clique sur Create personal access token.

![Create personal access token](images/config_access_token.png)

Il sera généré et apparaitra en haut. Tu peux maintenant le copier auprès de la clé `CI_PUSH_TOKEN` dans le fichier Compagnon.md.

Nous avons maintenant toutes les variables requises pour programmer l'automatisation.

### Configurer les variables d'environnement du projet

Nous allons maintenant prendre toutes les informations que nous avons accumulées dans le fichier Compagnon.md et les mettre dans GitLab.

Nous allons retourner à notre projet par le menu principal en haut à gauche

![menu principal projets](images/menu_acces_projets.png)

Dans la section Settings, nous allons aller ensuite dans CI/CD

![CI/CD](images/settings_cicd.png)

Dans la section Variables, clique sur Expand. En utilisant le bouton Add variable, nous allons insérer les 3 valeurs que nous avons inscrites dans le fichier Compagnon.md. Le deux-points `:` sépare les clés (Key) des valeurs (Value).

Le tableau complété devrait ressembler à ceci:

![tableau des variables](images/tableau_variables_cicd.png)

Nous allons maintenant configurer le script qui fait la sauvegarde.

### Configurer les script qui fera la sauvegarde

Revenons aux fichiers du projet par le menu de gauche: `Repository` puis `Files`.

En haut vers le centre, il y a un bouton `+`. Clique dessus, puis choisis `New File`

![New File](images/gitlab_newfile.png)

Nous allons nommer le fichier `.gitlab-ci.yml`. Le point au début est important.

Nous allons y mettre le contenu du fichier `_gitlab-ci.yml` que tu as téléchargé avec ce manuel dans l'éditeur de code de la page. 

La raison pourquoi nous le faisons manuellement est que les fichiers avec un point au début sont parfois cachés sur les systèmes. Sinon, ils sont aussi pour déclencher des actions automatiques, ce que je ne souhaitais pas pour le dépôt de ma formation, alors c'est juste mieux parfois d'y aller manuellement.

![New File .gitlab-ci.yml](images/new_file_gitlab_ci.png)

Je vais aussi te demander de copier le contenu des fichiers

- `envset.sh`, 
- `merge_gen.sh`,
- `convertkit-backup.py` 

dans le même répertoire.

Tu peux maintenant faire un commit, qui est l'équivalent d'une sauvegarde dans le monde du CI/CD.

Nous allons maintenant aller voir ce qu'il se passe après le commit. Le principe de l'intégration continue, c'est qu'à chaque commit, on exécute le programme `.gitlab-ci.yml` qui sert, dans le monde logiciel, à compiler et tester chaque nouvelle version avant de la rendre disponible aux clients.

Dans le menu de gauche, il faut aller dans `CI/CD`, puis `Pipelines`.

Tu verras qu'il y a une exécution à Failed et c'est normal.

![exécution à Failed](images/gitlab_cicd_pipeline_fail_validate_account.png)

### Configurer la carte de crédit pour activer les runners.

Depuis 2021, GitLab demande une carte de crédit pour utiliser la fonctionnalité CI/CD avec les 400 minutes gratuites offertes. Ceci est pour limiter l'exploitation des ressources par la création de comptes multiples.

Tu dois donc à cette étape-ci, cliquer sur `Validate your account`.

![Validate your account](images/gitlab_validate_user_acct.png)

Après avoir entré tes informations de crédit et résolu le Captcha, tu verras ce message en haut de la page.

> Your account has been validated
> You'll now be able to take advantage of free CI/CD minutes on shared runners.

![account validated](images/gitlab_account_validated.png)

### Programmer le séquenceur

Nous allons programmer le séquenceur pour l'exécution périodique de la sauvegarde è chaque semaine.

Dans le menu de gauche, aller dans `CI/CD`, puis `Schedules`.

![Schedules](images/gitlab_cicd_schedules.png)

Clique `New Schedule`, puis remplis le formulaire comme suit.

Le second nombre dans la section `Interval Pattern` / `Custom` est l'heure d'exécution. Le format utilisé est nommé `cron`. Il s'agit d'une syntaxe standard pour la planification de tâches sur Linux.

Ici, dans l'exemple, le script va rouler chaque jeudi à 13h00.

![Interval Pattern](images/gitlab_convertkit_schedule_pipeline.png)

### Exécuter une première fois

Clique le triangle (play) pour lancer le pipeline.

![](images/gitlab_pipeline_schedule_click_play.png)

Lors de l'exécution, le pipeline a un statut à `running`.

![running](images/gitlab_pipeline_running.png)

Lorsque c'est complété, le pipeline a un statut à `passed`.

![passed](images/gitlab_pipeline_success.png)

Retourne maintenant dans le projet

![menu principal projets](images/menu_acces_projets.png)

Tu peux maintenant voir un dossier `json` qui contient la sauvegarde de ton compte ConvertKit.

## Conclusion

J'espère que tu as apprécié cette formation.

Pour toute question, je t'invite à communiquer avec moi via <mailto:apprenant@jevalide.ca>

Merci et à bientôt !

François

L'allié de ton autonomie numérique

## Licence

![](images/cc-by-nc-sa.png)

Ce(tte) \{oe}uvre est mise à disposition selon les termes de la [Licence Creative Commons Attribution - Pas d'Utilisation Commerciale - Partage dans les Mêmes Conditions 4.0 International](https://creativecommons.org/licenses/by-nc-sa/4.0/).



